#!/bin/bash
#
# source: http://spuriousinterrupt.org/files/xfce4-notifyd/xfce4-notifyd-0.1.0.tar.bz2
#
# maintainer: gmg (g.monpontet@gmail.com)
#

soft='xfce4-notifyd'
softversion='0.1.0'
packageversion='60.2'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest

cd $src

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --mandir=/usr/man
  --localstatedir=/var

make -j2
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

rm -rf $dest/usr/share/icons/hicolor/48x48
mkdir -p $dest/usr/share/icons/hicolor/scalable/apps
cp $buildir/xfce4-notifyd.svg $dest/usr/share/icons/hicolor/scalable/apps

# Description file

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

             |-----handy-ruler---------------------------------------------------|
xfce4-notifyd: xfce4-notifyd - is a simple notification daemon for Xfce
xfce4-notifyd:
xfce4-notifyd: Xfce4-notifyd is a simple, visually-appealing notification daemon
xfce4-notifyd: for Xfce that implements the Freedesktop.org Desktop Notifications
xfce4-notifyd: Specification.
xfce4-notifyd:
xfce4-notifyd:
xfce4-notifyd:
xfce4-notifyd:
xfce4-notifyd:
xfce4-notifyd:
EODESC

rm -f $dest/usr/share/applications/*.desktop
cat << EOF > $dest/usr/share/applications/xfce4-notifyd-config.desktop
[Desktop Entry]
version=1.0
Name=Notifications
Name[ca]=Notificacions
Name[da]=Beskeder
Name[de]=Benachrichtigungen
Name[el]=Ειδοποιήσεις
Name[es]=Notificaciones
Name[fi]=Huomautukset
Name[fr]=Notifications
Name[id]=Notifikasi
Name[nb]=Varsling
Name[nl]=Notificaties
Name[pt_PT]=Notificações
Name[sq]=Njoftime
Name[tr]=Bildiriler
Comment=Customize how notifications appear on your screen
Comment[ca]=Personalitza com es mostren les notificacions
Comment[da]=Tilpas hvordan beskeder fremkommer på din skærm
Comment[de]=Das Erscheinungsbild von Benachrichtigungen anpassen
Comment[el]=Προσαρμογή του τρόπου εμφάνισης των ειδοποιήσεων στην οθόνη
Comment[es]=Personalice cómo aparecen las notificaciones en la pantalla
Comment[fi]=Mukauta näytöllesi ilmestyvien huomautusten toimintaa
Comment[fr]=Personnaliser les notifications système
Comment[id]=Sesuaikan bagaimana notifikasi tampak di layar anda
Comment[nb]=Tilpass visning av varsler på skjermen din
Comment[nl]=Weergave van notificaties instellen
Comment[pt_PT]=Personalizar como as notificações aparecem no monitor 
Comment[sq]=Përshtasni mënyrën se si shfaqen njoftimet në ekranin tuaj
Comment[tr]=Bildirilerin görünümünü özelleştirin
Exec=xfce4-notifyd-config
Icon=xfce4-notifyd
Terminal=false
StartupNotify=true
Type=Application
Categories=X-XFCE;Settings;DesktopSettings;X-XfceSettingsDialog;
X-XfcePluggable=true
EOF

cat <<-EOF > $dest/install/doinst.sh
if [ -x usr/bin/gtk-update-icon-cache ]; then
chroot . /gtk-update-icon-cache -f -t /usr/share/icons/hicolor 1>/dev/null 2>&1
fi
EOF

# Documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING INSTALL NEWS README TODO \
$dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging
cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5